==> async-mysql-query-0.0.1.tgz: package/test/test.js <==
const database = require('../index.js')

const db = new database()


let sql = 
`
create table USER_INFO(
	id varchar(50) not null,
	name varchar(50) not null,
	isLike varchar(50) not null,
	primary key (id)
)
`
//db.createTable(sql,cb)

let info = {
	name:'joker177',
	isLike:'kk',
}
let random = Math.random()*10

let iin = {
	name:'commit success again',
	isLike:'kk',
	id:random
}
let iiin = ['USER_INFO',['name','isLike','id'],['raw_insert','awesome',random]]

let val = {id:'00001111'}


//db.insert('USER_INFO',iin).then(k=>console.log(k)).catch(err=>{console.log(err)})
//db.raw_insert(iiin).then(t=>console.log(t)).catch(e=>console.log(e))
// db.update('USER_INFO',info,val)
// .then(t=>console.log(t))
// .catch(err=>console.log(err))

// let del = {id:'123'}

// db.delete('USER_INFO',del)
// .then(t=>console.log(t))
// .catch(err=>console.log(err))

// let sel = {
// 	name:'until123',
// 	isLike:'kk'
// }

//db.select('USER_INFO',sel).then(t=>console.log(t)).catch(err=>console.log(err))

//db.countTable('USER_INFO').then(txt=>console.log(txt)).catch(err=>console.log(err))

let _sql = `select ?? from ?? where name = ? and isLike = ?`
let params = [['id','name','isLike'],'USER_INFO','util123','kk']

//db.selectByParams(_sql,params).then(t=>console.log(t)).catch(e=>console.log(e))

let count_sql = 'select count(*) as count from ?? where name = ? and isLike = ? '
let count_params = ['USER_INFO','util123','kk']

//db.selectByParams(count_sql,count_params).then(t=>console.log(t)).catch(e=>console.log(e))

let page_sql = 'select ?? from ?? where name = ? and isLike = ? order by id desc limit ?,?'
let pageParams = [['id','name','isLike'],'USER_INFO','util123','kk',0,2]

//db.selectByPages(page_sql,pageParams).then(t=>console.log(t)).catch(e=>console.log(e))

// db.update(['USER_INFO',{isLike:'fuck',id:'999333'},{name:'joker2'}])
// .then(t=>console.log(t))
// .catch(e=>console.log(e))

let sql_y = 'delete from ?? where name = ? and isLike = ?'
let arr = ['user_info','joker2','fuck']
db.raw_delete(sql_y,arr).then(t=>console.log(t)).catch(e=>console.log(e))

==> async-mysql-query-0.0.2.tgz: package/test/test.js <==

const database = require('../index.js')

const db = new database({
	host:'your host',
    user:'your username',
    password:'your pwd',
    database:'chosed database'
})

const vps = new database()

vps.countTable('user_info').then(r=>console.log('userinfo',r)).catch(e=>console.log(e))
async function testend(){
	let count = await vps.countTable('user_info')
	vps.endPool()
	vps.showPool()
}
testend()
//db.toString()

let sql = 
`
create table USER_INFO(
	id varchar(50) not null,
	name varchar(50) not null,
	isLike varchar(50) not null,
	primary key (id)
)
`
//db.createTable(sql,cb)

let info = {
	name:'joker177',
	isLike:'kk',
}
let random = Math.random()*10

let iin = {
	name:'commit success again',
	isLike:'kk',
	id:random
}
let iiin = ['USER_INFO',['name','isLike','id'],['raw_insert','awesome',random]]

let val = {id:'00001111'}


//db.insert('USER_INFO',iin).then(k=>console.log(k)).catch(err=>{console.log(err)})
//db.raw_insert(iiin).then(t=>console.log(t)).catch(e=>console.log(e))
// db.update('USER_INFO',info,val)
// .then(t=>console.log(t))
// .catch(err=>console.log(err))

// let del = {id:'123'}

// db.delete('USER_INFO',del)
// .then(t=>console.log(t))
// .catch(err=>console.log(err))

// let sel = {
// 	name:'until123',
// 	isLike:'kk'
// }

//db.select('USER_INFO',sel).then(t=>console.log(t)).catch(err=>console.log(err))

//db.countTable('USER_INFO').then(txt=>console.log(txt)).catch(err=>console.log(err))

let _sql = `select ?? from ?? where name = ? and isLike = ?`
let params = [['id','name','isLike'],'USER_INFO','util123','kk']

//db.selectByParams(_sql,params).then(t=>console.log(t)).catch(e=>console.log(e))

let count_sql = 'select count(*) as count from ?? where name = ? and isLike = ? '
let count_params = ['USER_INFO','util123','kk']

//db.selectByParams(count_sql,count_params).then(t=>console.log(t)).catch(e=>console.log(e))

let page_sql = 'select ?? from ?? where name = ? and isLike = ? order by id desc limit ?,?'
let pageParams = [['id','name','isLike'],'USER_INFO','util123','kk',0,2]

//db.selectByPages(page_sql,pageParams).then(t=>console.log(t)).catch(e=>console.log(e))

// db.update(['USER_INFO',{isLike:'fuck',id:'999333'},{name:'joker2'}])
// .then(t=>console.log(t))
// .catch(e=>console.log(e))

let sql_y = 'delete from ?? where name = ? and isLike = ?'
let arr = ['user_info','joker2','fuck']
//db.raw_delete(sql_y,arr).then(t=>console.log(t)).catch(e=>console.log(e))

//db.countTable('ROMS_SZ_TASK').then(r=>console.log(r)).catch(e=>console.log(e))

let sel_sql = 'select ?? from ?? where staffId = ?'
let sel_params = [['deviceTypeId','num','createtime'],'ROMS_SZ_STAFFAUTH','d4665b7d-afcc-4c7d-afcb-e35ec4407d47']
// db.selectByParams(sel_sql,sel_params)
// .then(r=>console.log(r.result))
// .catch(e=>console.log(e))

async function test(){
	let ok = await db.selectByParams(sel_sql,sel_params)

	ok.result.forEach(i=>console.log(i.num))

}

//test()
